# AxsDB TODO list

- Interpolation
  - [ ] Consider parallel execution for independent dimension groups
  - [ ] Investigate numba parallel option for gufuncs
  - [ ] Cache compiled numba functions more aggressively
  - [ ] Consider supporting additional interpolation methods (nearest, cubic)
